<?php

namespace Drupal\monarch_migration_d7\Plugin\MigrationMapper;

use Drupal\migrate\Row;
use Drupal\monarch_migration\Plugin\MigrationMapper\MigrationMapperBase;

/**
 * Maps fields.
 *
 * @MigrationMapper(
 *   id = "monarch_migration_d7_taxonomy_term",
 *   migration = "taxonomy_term",
 *   weight = -9999,
 * )
 */
class TaxonomyTerm extends MigrationMapperBase {

  /**
   * {@inheritdoc}
   */
  public function processRow(Row $row) {
    $row->setDestinationProperty('tid', $row->getSourceProperty('tid'));
    $row->setDestinationProperty('revision_id', $row->getSourceProperty('tid'));
    $row->setDestinationProperty('vid', $row->getSourceProperty('machine_name'));
    $row->setDestinationProperty('name', $row->getSourceProperty('name'));
    $row->setDestinationProperty('weight', $row->getSourceProperty('weight'));
    $row->setDestinationProperty('changed', $row->getSourceProperty('timestamp'));
    $row->setDestinationProperty('langcode', $row->getSourceProperty('language'));
    $row->setDestinationProperty('description', [
      'value' => $row->getSourceProperty('description'),
      'format' => $row->getSourceProperty('format'),
    ]);

    $parent_id = $row->getSourceProperty('parent');

    while (is_array($parent_id)) {
      $parent_id = reset($parent_id);
    }

    if (!empty($parent_id)) {
      $looked_up_parent_id = $this->executePlugin('migration_lookup', $parent_id, $row, [
        'migration' => ['taxonomy_term'],
      ]);

      $row->setDestinationProperty('parent_id', $looked_up_parent_id);
    }
  }

}
